@@ -19,6 +19,6 @@ def prometheus_log_method(handler):
     """
     HTTP_REQUEST_DURATION_SECONDS.labels(
         method=handler.request.method,
-        handler='{}.{}'.format(handler.__class__.__module__, type(handler).__name__),
+        handler=f'{handler.__class__.__module__}.{type(handler).__name__}',
         status_code=handler.get_status()
     ).observe(handler.request.request_time())
