@@ -1,7 +1,6 @@
 """Test the kernels service API."""
 
 import json
-import sys
 import time
 
 from requests import HTTPError
@@ -24,7 +23,7 @@ except ImportError:
     async_testing_enabled = False
 
 
-class KernelAPI(object):
+class KernelAPI:
     """Wrapper for kernel REST API requests"""
     def __init__(self, request, base_url, headers):
         self.request = request
@@ -204,13 +203,11 @@ class AsyncKernelAPITest(KernelAPITest):
     def setup_class(cls):
         if not async_testing_enabled:  # Can be removed once jupyter_client >= 6.1 is required.
             raise SkipTest("AsyncKernelAPITest tests skipped due to down-level jupyter_client!")
-        if sys.version_info < (3, 6):  # Can be removed once 3.5 is dropped.
-            raise SkipTest("AsyncKernelAPITest tests skipped due to Python < 3.6!")
-        super(AsyncKernelAPITest, cls).setup_class()
+        super().setup_class()
 
     @classmethod
     def get_argv(cls):
-        argv = super(AsyncKernelAPITest, cls).get_argv()
+        argv = super().get_argv()
 
         # before we extend the argv with the class, ensure that appropriate jupyter_client is available.
         # if not available, don't set kernel_manager_class, resulting in the repeat of sync-based tests.
@@ -237,16 +234,20 @@ class KernelFilterTest(NotebookTestBase):
         self.assertEqual(self.notebook.kernel_manager.allowed_message_types, ['kernel_info_request'])
 
 
+CULL_TIMEOUT = 5
+CULL_INTERVAL = 1
+
+
 class KernelCullingTest(NotebookTestBase):
     """Test kernel culling """
 
     @classmethod
     def get_argv(cls):
-        argv = super(KernelCullingTest, cls).get_argv()
+        argv = super().get_argv()
 
-        # Enable culling with 2s timeout and 1s intervals
-        argv.extend(['--MappingKernelManager.cull_idle_timeout=2',
-                     '--MappingKernelManager.cull_interval=1',
+        # Enable culling with 5s timeout and 1s intervals
+        argv.extend([f'--MappingKernelManager.cull_idle_timeout={CULL_TIMEOUT}',
+                     f'--MappingKernelManager.cull_interval={CULL_INTERVAL}',
                      '--MappingKernelManager.cull_connected=False'])
         return argv
 
@@ -270,8 +271,9 @@ class KernelCullingTest(NotebookTestBase):
         assert self.get_cull_status(kid)  # not connected, should be culled
 
     def get_cull_status(self, kid):
+        frequency = 0.5
         culled = False
-        for i in range(15):  # Need max of 3s to ensure culling timeout exceeded
+        for _ in range(int((CULL_TIMEOUT + CULL_INTERVAL)/frequency)):  # Timeout + Interval will ensure cull
             try:
                 self.kern_api.get(kid)
             except HTTPError as e:
@@ -279,5 +281,5 @@ class KernelCullingTest(NotebookTestBase):
                 culled = True
                 break
             else:
-                time.sleep(0.2)
+                time.sleep(frequency)
         return culled
