@@ -99,7 +99,7 @@ def find_package_data():
     """
     # This is not enough for these things to appear in a sdist.
     # We need to muck with the MANIFEST to get this to work
-    
+
     # exclude components and less from the walk;
     # we will build the components separately
     excludes = [
@@ -119,12 +119,12 @@ def find_package_data():
             continue
         for f in files:
             static_data.append(pjoin(parent, f))
-    
+
     # for verification purposes, explicitly add main.min.js
     # so that installation will fail if they are missing
     for app in ['auth', 'edit', 'notebook', 'terminal', 'tree']:
         static_data.append(pjoin('static', app, 'js', 'main.min.js'))
-    
+
     components = pjoin("static", "components")
     # select the components we actually need to install
     # (there are lots of resources we bundle for sdist-reasons that we don't actually use)
@@ -135,6 +135,7 @@ def find_package_data():
         pjoin(components, "bootstrap-tour", "build", "js", "bootstrap-tour.min.js"),
         pjoin(components, "create-react-class", "index.js"),
         pjoin(components, "font-awesome", "css", "*.css"),
+        pjoin(components, "google-caja", "html-css-sanitizer-minified.js"),
         pjoin(components, "es6-promise", "*.js"),
         pjoin(components, "font-awesome", "fonts", "*.*"),
         pjoin(components, "jed", "jed.js"),
@@ -173,10 +174,10 @@ def find_package_data():
         mj('config', 'TeX-AMS-MML_HTMLorMML-full.js'),
         mj('config', 'Safe.js'),
     ])
-    
+
     trees = []
     mj_out = mj('jax', 'output')
-    
+
     if os.path.exists(mj_out):
         for output in os.listdir(mj_out):
             path = pjoin(mj_out, output)
@@ -210,7 +211,7 @@ def find_package_data():
         'notebook.services.api': ['api.yaml'],
         'notebook.i18n': ['*/LC_MESSAGES/*.*'],
     }
-    
+
     return package_data
 
 
@@ -229,7 +230,7 @@ def check_package_data(package_data):
 
 def check_package_data_first(command):
     """decorator for checking package_data before running a given command
-    
+
     Probably only needs to wrap build_py
     """
     class DecoratedCommand(command):
@@ -361,21 +362,21 @@ class CompileBackendTranslation(Command):
 
 class Bower(Command):
     description = "fetch static client-side components with bower"
-    
+
     user_options = [
         ('force', 'f', "force fetching of bower dependencies"),
     ]
-    
+
     def initialize_options(self):
         self.force = False
-    
+
     def finalize_options(self):
         self.force = bool(self.force)
-    
+
     bower_dir = pjoin(static, 'components')
     node_modules = pjoin(repo_root, 'node_modules')
     sanitizer_dir = pjoin(bower_dir, 'sanitizer')
-    
+
     def should_run(self):
         if self.force:
             return True
@@ -402,15 +403,15 @@ class Bower(Command):
         if not self.should_run():
             print("bower dependencies up to date")
             return
-        
+
         if self.should_run_npm():
             print("installing build dependencies with npm")
             run(['npm', 'install'], cwd=repo_root)
             os.utime(self.node_modules, None)
-        
+
         env = os.environ.copy()
         env['PATH'] = npm_path
-        
+
         try:
             run(
                 ['bower', 'install', '--allow-root', '--config.interactive=false'],
@@ -453,9 +454,9 @@ def patch_out_bootstrap_bw_print():
 
 class CompileCSS(Command):
     """Recompile Notebook CSS
-    
+
     Regenerate the compiled CSS from LESS sources.
-    
+
     Requires various dev dependencies, such as require and lessc.
     """
     description = "Recompile Notebook CSS"
@@ -479,7 +480,7 @@ class CompileCSS(Command):
         env['PATH'] = npm_path
 
         patch_out_bootstrap_bw_print()
-        
+
         for src, dst in zip(self.sources, self.targets):
             try:
                 run(['lessc',
@@ -498,7 +499,7 @@ class CompileCSS(Command):
 
 class CompileJS(Command):
     """Rebuild Notebook Javascript main.min.js files and translation files.
-    
+
     Calls require via build-main.js
     """
     description = "Rebuild Notebook Javascript main.min.js files"
@@ -514,7 +515,7 @@ class CompileJS(Command):
 
     apps = ['notebook', 'tree', 'edit', 'terminal', 'auth']
     targets = [ pjoin(static, app, 'js', 'main.min.js') for app in apps ]
-    
+
     def sources(self, name):
         """Generator yielding .js sources that an application depends on"""
         yield pjoin(repo_root, 'tools', 'build-main.js')
@@ -535,7 +536,7 @@ class CompileJS(Command):
                 continue
             for f in files:
                 yield pjoin(parent, f)
-    
+
     def should_run(self, name, target):
         if self.force or not os.path.exists(target):
             return True
@@ -582,13 +583,13 @@ class JavascriptVersion(Command):
     """write the javascript version to notebook javascript"""
     description = "Write Jupyter version to javascript"
     user_options = []
-    
+
     def initialize_options(self):
         pass
-    
+
     def finalize_options(self):
         pass
-    
+
     def run(self):
         nsfile = pjoin(repo_root, "notebook", "static", "base", "js", "namespace.js")
         with open(nsfile) as f:
@@ -597,7 +598,7 @@ class JavascriptVersion(Command):
             found = False
             for line in lines:
                 if line.strip().startswith("Jupyter.version"):
-                    line = '    Jupyter.version = "{0}";\n'.format(version)
+                    line = f'    Jupyter.version = "{version}";\n'
                     found = True
                 f.write(line)
             if not found:
